@@ -5,7 +5,7 @@
 #  open source, and has the attribution requirements (GPL Section 7) at
 #  http://statnet.org/attribution
 #
-#  Copyright 2003-2013 Statnet Commons
+#  Copyright 2003-2014 Statnet Commons
 #######################################################################
 ##################################################################################
 # The <ergm.estimate> function searches for and returns a maximizer of the
@@ -155,18 +155,21 @@ ergm.estimate<-function(init, model, statsmatrix, statsmatrix.obs=NULL,
     loglikelihoodfn <- switch(metric,
                               Likelihood=llik.fun.obs,
                               lognormal=llik.fun.obs,
+                              logtaylor=llik.fun.obs,
                               Median.Likelihood=llik.fun.obs,
                               EF.Likelihood=llik.fun.obs,
                               llik.fun.obs.robust)
     gradientfn <- switch(metric,
                          Likelihood=llik.grad.obs,
                          lognormal=llik.grad.obs,
+                         logtaylor=llik.grad.obs,
                          Median.Likelihood=llik.grad.obs,
                          EF.Likelihood=llik.grad.obs,
                          llik.grad.obs)
     Hessianfn <- switch(metric,
                         Likelihood=llik.hessian.obs,
                         lognormal=llik.hessian.obs,
+                        logtaylor=llik.hessian.obs,
                         Median.Likelihood=llik.hessian.obs,
                         EF.Likelihood=llik.hessian.obs,
                         llik.hessian.obs)
@@ -174,18 +177,21 @@ ergm.estimate<-function(init, model, statsmatrix, statsmatrix.obs=NULL,
     loglikelihoodfn <- switch(metric,
                               Likelihood=llik.fun,
                               lognormal=llik.fun,
+                              logtaylor=llik.fun.logtaylor,
                               Median.Likelihood=llik.fun.median,
                               EF.Likelihood=llik.fun.EF,
                               llik.fun2)
     gradientfn <- switch(metric,
                          Likelihood=llik.grad,
                          lognormal=llik.grad,
+                         logtaylor=llik.grad,
                          Median.Likelihood=llik.grad,
                          EF.Likelihood=llik.grad,
                          llik.grad)
     Hessianfn <- switch(metric,
                         Likelihood=llik.hessian,
                         lognormal=llik.hessian,
+                        logtaylor=llik.hessian,
                         Median.Likelihood=llik.hessian,
                         EF.Likelihood=llik.hessian,
                         llik.hessian)
@@ -198,7 +204,7 @@ ergm.estimate<-function(init, model, statsmatrix, statsmatrix.obs=NULL,
   if (all(model$etamap$canonical==1) && 
       (metric=="lognormal" || metric=="Likelihood")) {
     if (obsprocess) {
-      if (verbose) { cat("Using log-normal approx with obsing (no optim)\n") }
+      if (verbose) { cat("Using log-normal approx with missing (no optim)\n") }
       Lout <- list(hessian = -(V-V.obs))
     } else {
       if (verbose) { cat("Using log-normal approx (no optim)\n") }
@@ -281,7 +287,7 @@ ergm.estimate<-function(init, model, statsmatrix, statsmatrix.obs=NULL,
                         hessian=hessianflag,
                         method="Nelder-Mead",
                         control=list(trace=trace,fnscale=-1,maxit=100*nr.maxit,
-                                     reltol=0.01),
+                                     reltol=nr.reltol),
                         xobs=xobs, 
                         xsim=xsim, probs=probs, 
                         xsim.obs=xsim.obs, probs.obs=probs.obs,
@@ -321,6 +327,7 @@ ergm.estimate<-function(init, model, statsmatrix, statsmatrix.obs=NULL,
     #  and hence the MCMC s.e.
     #
     mc.se <- rep(NA, length=length(theta))
+    mc.cov <- matrix(NA, length(theta), length(theta))
     covar <- NA
     if(!hessianflag){
       #  covar <- robust.inverse(cov(xsim))
@@ -343,24 +350,19 @@ ergm.estimate<-function(init, model, statsmatrix, statsmatrix.obs=NULL,
     
     if(calc.mcmc.se){
       if (verbose) { cat("Starting MCMC s.e. computation.\n") }
-      if ((metric=="lognormal" || metric=="Likelihood")
-          && length(model$etamap$curved)==0) {
-        mc.se <- ergm.MCMCse.lognormal(theta=theta, init=init, 
-                                       statsmatrix=statsmatrix0, 
-                                       statsmatrix.obs=statsmatrix.obs,
-                                       H=V, H.obs=V.obs,
-                                       model=model)
-      } else {
-        MCMCse <- ergm.MCMCse(theta=theta,init=init, 
-                             statsmatrix=statsmatrix0,
-                             statsmatrix.obs=statsmatrix.obs,
-                             model=model)
-        mc.se <- MCMCse$mc.se
-#       The next line forces the s.e. in summary.ergm to combine
-#       the hessian of the likelihood plus the MCMC s.e.
-#       covar <- MCMCse$mc.cov+covar
-#       If the above line is commented out only the hessian of the likelihood 
-#       is used.
+      mc.cov <-
+        if ((metric=="lognormal" || metric=="Likelihood")
+            && length(model$etamap$curved)==0) {
+          ergm.MCMCse.lognormal(theta=theta, init=init, 
+                                statsmatrix=statsmatrix0, 
+                                statsmatrix.obs=statsmatrix.obs,
+                                H=V, H.obs=V.obs,
+                                model=model)
+        } else {
+        ergm.MCMCse(theta=theta,init=init, 
+                    statsmatrix=statsmatrix0,
+                    statsmatrix.obs=statsmatrix.obs,
+                    model=model)
       }
     }
     c0  <- loglikelihoodfn(theta=Lout$par, xobs=xobs,
@@ -406,7 +408,7 @@ ergm.estimate<-function(init, model, statsmatrix, statsmatrix.obs=NULL,
                           MCMCtheta=init, 
                           loglikelihood=loglikelihood, gradient=gradient, hessian=Lout$hessian,
                           covar=covar, failure=FALSE,
-                          mc.se=mc.se#, #acf=mcmcacf,
+                          mc.cov=mc.cov #, #acf=mcmcacf,
                           #fullsample=statsmatrix.all
                           ),
                         class="ergm"))
