@@ -5,7 +5,7 @@
 #  open source, and has the attribution requirements (GPL Section 7) at
 #  http://statnet.org/attribution
 #
-#  Copyright 2003-2013 Statnet Commons
+#  Copyright 2003-2014 Statnet Commons
 #######################################################################
 ###############################################################################
 # The <ergm.pl> function prepares many of the components needed by <ergm.mple>
@@ -70,6 +70,7 @@ ergm.pl<-function(Clist, Clist.miss, m, theta.offset=NULL,
   maxNumDyadTypes <- min(control$MPLE.max.dyad.types,
                          ifelse(bip>0, bip*(n-bip), 
                                 ifelse(Clist$dir, n*(n-1), n*(n-1)/2)))
+                        
   # May have to think harder about what maxNumDyadTypes should be if we 
   # implement a hash-table approach to compression.
   if(is.null(conddeg)){
@@ -78,8 +79,7 @@ ergm.pl<-function(Clist, Clist.miss, m, theta.offset=NULL,
           as.integer(Clist$tails), as.integer(Clist$heads),
           as.integer(Clist$nedges),
           as.integer(FALSE),
-          as.integer(Clist.miss$tails), as.integer(Clist.miss$heads),
-          as.integer(Clist.miss$nedges),
+          as.integer(c(Clist.miss$nedges,Clist.miss$tails,Clist.miss$heads)),
           as.integer(n), 
           as.integer(Clist$dir),     as.integer(bip),
           as.integer(Clist$nterms), 
@@ -88,6 +88,7 @@ ergm.pl<-function(Clist, Clist.miss, m, theta.offset=NULL,
           y = integer(maxNumDyadTypes),
           x = double(maxNumDyadTypes*Clist$nstats),
           weightsvector = integer(maxNumDyadTypes),
+          as.integer(.Machine$integer.max), # maxDyads
           as.integer(maxNumDyadTypes),
           PACKAGE="ergm")
   uvals <- z$weightsvector!=0
@@ -95,10 +96,61 @@ ergm.pl<-function(Clist, Clist.miss, m, theta.offset=NULL,
     cat(paste("MPLE covariate matrix has", sum(uvals), "rows.\n"))
   }
   zy <- z$y[uvals]
-  wend <- z$weightsvector[uvals]
+  wend <- as.numeric(z$weightsvector[uvals])
   xmat <- matrix(z$x, ncol=Clist$nstats, byrow=TRUE)[uvals,,drop=FALSE]
   colnames(xmat) <- m$coef.names
   rm(z,uvals)
+
+  # If we ran out of space, AND we have a sparse network, then, use
+  # case-control MPLE.
+  if(sum(wend)<Clist$ndyads && mean(zy)<1/2){
+    if(verbose) cat("A sparse network with too many unique dyads encountered. Using case-control MPLE.\n")
+    # Strip out the rows associated with ties.
+    wend <- wend[zy==0]
+    xmat <- xmat[zy==0,,drop=FALSE]
+    zy <- zy[zy==0]
+
+    ## Run a whitelist PL over all of the edges in the network.
+    # Generate a random permutation of edges, in case we run out of space here as well.
+    missing <- paste(Clist$tails,Clist$heads,sep=".") %in% paste(Clist.miss$tails,Clist.miss$heads,sep=".")
+    ordering <- sample.int(Clist$nedges-sum(missing))
+    z <- .C("MPLE_wrapper",
+            as.integer(Clist$tails), as.integer(Clist$heads),
+            as.integer(Clist$nedges),
+            as.integer(TRUE),
+            as.integer(c(Clist$nedges-sum(missing),Clist$tails[!missing][ordering],Clist$heads[!missing][ordering])),
+            as.integer(n), 
+            as.integer(Clist$dir),     as.integer(bip),
+            as.integer(Clist$nterms), 
+            as.character(Clist$fnamestring), as.character(Clist$snamestring),
+            as.double(Clist$inputs),
+            y = integer(maxNumDyadTypes),
+            x = double(maxNumDyadTypes*Clist$nstats),
+            weightsvector = integer(maxNumDyadTypes),
+            as.integer(.Machine$integer.max), # maxDyads
+            as.integer(maxNumDyadTypes),
+            PACKAGE="ergm")
+    uvals <- z$weightsvector!=0
+    zy.e <- z$y[uvals]
+    wend.e <- as.numeric(z$weightsvector[uvals])
+    xmat.e <- matrix(z$x, ncol=Clist$nstats, byrow=TRUE)[uvals,,drop=FALSE]
+    colnames(xmat.e) <- m$coef.names
+    rm(z,uvals)
+
+    # Divvy up the sampling weight of the ties:
+    wend.e.total <- (Clist$nedges-sum(missing))
+    wend.e <- wend.e / sum(wend.e) * wend.e.total
+
+    # Divvy up the sampling weight of the nonties:
+    wend <- wend / sum(wend) * (Clist$ndyads-wend.e.total)
+
+    zy <- c(zy,zy.e)
+    wend <- c(wend, wend.e)
+    xmat <- rbind(xmat, xmat.e)
+
+    rm(zy.e, wend.e, xmat.e)
+  }
+  
   }else{
     if (verbose) {
       cat("Using the MPLE conditional on degree.\n")
@@ -192,13 +244,23 @@ ergm.pl<-function(Clist, Clist.miss, m, theta.offset=NULL,
 
   #
   # Adjust for the offset
-  #
+  # =======================
+  # Helper function
+  # A is a matrix. V is a column vector that may contain Infs
+  # computes A %*% V, counting 0*Inf as 0
+  # May be slow if there are many rows. Use C here?
+  multiply.with.inf <- function(A,V) {
+    cbind(sapply(seq_len(nrow(A)), function(i) sum(V * A[i,], na.rm=T)))
+  }
+
   if(any(m$etamap$offsettheta)){
     if(any(is.na(theta.offset[m$etamap$offsettheta]))){
       stop("Offset terms without offset coefficients specified!")
     }
-    foffset <- xmat[,m$etamap$offsettheta,drop=FALSE] %*% cbind(theta.offset[m$etamap$offsettheta]) # Compute the offset's effect.
-    foffset[is.nan(foffset)] <- 0 # 0*Inf==0 in this case.
+    # Compute the offset's effect.
+    foffset <- multiply.with.inf(xmat[,m$etamap$offsettheta,drop=FALSE], 
+                                 cbind(theta.offset[m$etamap$offsettheta])) 
+    
     # Remove offset covariate columns.
     xmat <- xmat[,!m$etamap$offsettheta,drop=FALSE] 
     colnames(xmat) <- m$coef.names[!m$etamap$offsettheta]
