@@ -5,7 +5,7 @@
 #  open source, and has the attribution requirements (GPL Section 7) at
 #  http://statnet.org/attribution
 #
-#  Copyright 2003-2013 Statnet Commons
+#  Copyright 2003-2014 Statnet Commons
 #######################################################################
 #==============================================================
 # This file contains the following 21 utility functions:
@@ -19,6 +19,7 @@
 #      <rspartnerdist>         
 #      <twopathdist>            <copy.named>
 #      <compress.data.frame>    <sort.data.frame>
+#      <catchToList>
 #==============================================================      
 
 
@@ -469,6 +470,8 @@ get.free.dyads <- function(constraints){
 }
 
 get.miss.dyads <- function(constraints, constraints.obs){
+# Returns a network indicating the missing dyads in the network (
+# (respecting the constraints).
   free.dyads <- get.free.dyads(constraints)
   free.dyads.obs <- get.free.dyads(constraints.obs)
   
@@ -513,8 +516,41 @@ which.package.InitFunction <- function(f, env = parent.frame()){
   f <- as.character(f)
   # Find the first entity named f in the search path, and get its name
   # attribute (if present).
-  loc <- attr(findFunction(f, where=env)[[1]], "name")
-  # If name attribute is not NULL and begins with "package:", return
-  # the package name. Otherwise, return NULL.
-  if(!is.null(loc) && grepl("^package:", loc)) sub("^package:", "", loc) else NULL
+  found <- findFunction(f, where=env)
+  if (length(found) > 0) {
+    loc <- attr(found[[1]], "name")
+    # If name attribute is not NULL and begins with "package:", return
+    # the package name. Otherwise, return NULL.
+    if(!is.null(loc) && grepl("^package:", loc)) sub("^package:", "", loc) else NULL
+  } else {
+    # can't find the function normally; the package might have been imported
+    # instead of attached
+    found <- get(f, envir=env)
+    environmentName(environment(found))
+  }
+  
 }
+
+# Given a vector, truncate all infinite (or, really, bigger in
+# magnitude than replace=) values with replace= with the appropriate
+# sign. Leave NAs and NANs alone.
+.deinf <- function(x, replace=1/.Machine$double.eps) ifelse(is.nan(x) | abs(x)<replace, x, sign(x)*replace)
+
+
+
+# executes expression, returns the result in a list with any warnings and errors
+.catchToList <- function(expr) {
+  val <- NULL
+  myWarnings <- NULL
+  wHandler <- function(w) {
+    myWarnings <<- c(myWarnings, w$message)
+    invokeRestart("muffleWarning")
+  }
+  myError <- NULL
+  eHandler <- function(e) {
+    myError <<- e$message
+    NULL
+  }
+  val <- tryCatch(withCallingHandlers(expr, warning = wHandler), error = eHandler)
+  list(value = val, warnings = myWarnings, error=myError)
+} 
