@@ -5,7 +5,7 @@
 #  open source, and has the attribution requirements (GPL Section 7) at
 #  http://statnet.org/attribution
 #
-#  Copyright 2003-2013 Statnet Commons
+#  Copyright 2003-2014 Statnet Commons
 #######################################################################
 ###############################################################################
 # The <is.inCH> function determines whether a vector p is in the convex hull
@@ -30,14 +30,11 @@ is.inCH <- function(p, M) {
          "of first argument.")
   R = NROW(M)
   C=length(p)+1
-  if(require("Rglpk", quietly = TRUE)) {
+  
 	ans <- Rglpk_solve_LP(obj=c(p,-1), mat=cbind(rbind(p,M),-1),
                               dir=as.vector(rep("<=",R+1)), rhs=as.vector(c(1,rep(0,R))),
                               max=TRUE, bounds=list(lower=list(ind=1:C,val=rep(-Inf,C))))
-  }else{
-     stop("The 'Rglpk' package must be installed if the ergm control parameter 'style'='stepping' ")
-  }
-
+  
   if(ans$optimum==0){x<-TRUE}  #if the max is zero, the point q is in the CH of the points p
   else{x<-FALSE}              #if the max is strictly positive, q is not in the CH of p
   x
