@@ -5,7 +5,7 @@
  *  open source, and has the attribution requirements (GPL Section 7) at
  *  http://statnet.org/attribution
  *
- *  Copyright 2003-2013 Statnet Commons
+ *  Copyright 2003-2014 Statnet Commons
  */
 #include "MPLE.h"
 #include "changestat.h"
@@ -25,7 +25,7 @@
    statistics.  Note that two sets of statistics are considered
    unique in this context if the corresponding response values
    (i.e., dyad values, edge or no edge) are unequal.
-   The value maxNumDyadTypes is the largest allowable number of
+   The value maxDyadTypes is the largest allowable number of
    unique sets of change statistics.
  Re-rewritten by Pavel Krivitsky to make compression fast. ;)
  *****************/
@@ -34,12 +34,12 @@
    tails before heads now */
 
 void MPLE_wrapper(int *tails, int *heads, int *dnedges,
-		  int *wl, int *ltails, int *lheads, int *dlnedges,
+		  int *wl, int *lel,
 		  int *dn, int *dflag, int *bipartite, int *nterms, 
 		  char **funnames, char **sonames, double *inputs,  
 		  int *responsevec, double *covmat,
 		  int *weightsvector,
-		  int *maxNumDyadTypes){
+		  int *maxDyads, int *maxDyadTypes){
   Network nw[2];
   Vertex n_nodes = (Vertex) *dn; 
   Edge n_edges = (Edge) *dnedges;
@@ -52,8 +52,8 @@ void MPLE_wrapper(int *tails, int *heads, int *dnedges,
                           n_nodes, directed_flag, bip, 0, 0, NULL);
   m=ModelInitialize(*funnames, *sonames, &inputs, *nterms);
   
-  if(*wl) MpleInit_hash_wl(responsevec, covmat, weightsvector, ltails, lheads, *dlnedges, *maxNumDyadTypes, nw, m); 
-  else MpleInit_hash_bl(responsevec, covmat, weightsvector, ltails, lheads, *dlnedges, *maxNumDyadTypes, nw, m); 
+  if(*wl) MpleInit_hash_wl(responsevec, covmat, weightsvector, lel, *maxDyadTypes, nw, m); 
+  else MpleInit_hash_bl(responsevec, covmat, weightsvector, lel, *maxDyads, *maxDyadTypes, nw, m); 
 
   ModelDestroy(m);
   NetworkDestroy(nw);
@@ -134,62 +134,110 @@ numRows should, ideally, be a power of 2, but doesn't have to be.
 
 *****************/
 
+/* Maps a dyad ID to a tail and a head, serializing them in a
+   tail-major order.  Here, __s represent structural 0s.
+
+   Note that both undirected and directed unipartite networks are
+   serialized in the exact same manner. The t<h "filtering" or
+   swapping must be done later. (The alternative appears to require a
+   square root, which is inefficient.)
+
+   Bipartite(2 b1s, 3 b2s):
+
+          h
+
+   __ __ 00 01 02
+t  __ __ 03 04 05
+   __ __ __ __ __
+   __ __ __ __ __
+   __ __ __ __ __
+
+   Unipartite:
+
+          h
+
+   __ 00 01 02 03
+   04 __ 05 06 07
+t  08 09 __ 10 11 
+   12 13 14 __ 15 
+   16 17 18 19 __    
+
+ */
+
+// Note that id MUST be an integer of some sort, or you'll get floating point division.
+#define DYADID2T(id) (BIPARTITE ? id / (N_NODES-BIPARTITE) + 1 : id / (N_NODES-1) + 1)
+#define DYADID2H(id) (BIPARTITE ? id % (N_NODES-BIPARTITE) + 1 + BIPARTITE : \
+		      id % (N_NODES-1) + 1 + (id % (N_NODES-1) >= id / (N_NODES-1)))
+
+
+// Euclid's Algorithm to compute Greatest Common Divisor of a and b.
+unsigned long int gcd(unsigned long int a, unsigned long int b){
+  if(b==0) return a;
+  else return gcd(b, a%b);
+}
 
 void MpleInit_hash_bl(int *responsevec, double *covmat, int *weightsvector,
-		   int *bltails, int *blheads, Edge blnedges, 
-		   Edge maxNumDyadTypes, Network *nwp, Model *m){
+		      int *bl, 
+		      Edge maxDyads, Edge maxDyadTypes, Network *nwp, Model *m){
   double *newRow = (double *) R_alloc(m->n_stats,sizeof(double));
   /* Note:  This function uses macros found in changestat.h */
+
+  Dyad dc = DYADCOUNT(N_NODES, BIPARTITE, DIRECTED);
+  if(!BIPARTITE && !DIRECTED){
+    dc*=2;
+    maxDyads*=2;
+  }
   
+  // Find a number relatively prime with the dyad count:
+  Edge step = MAX(N_NODES/3,2);
+  while(gcd(dc,step)!=1) step++;
 
-  Edge blpos = 0;
-  for(Vertex t = 1; t <= (BIPARTITE ? BIPARTITE : N_NODES); t++){
-    for(Vertex h = MAX(DIRECTED ? 0 : t, BIPARTITE)+1; h <= N_NODES; h++){
-      if(h==t) continue;
+  for(Dyad d = 0, di = 0; d < MIN(maxDyads,dc); d++, di=(di+step)%dc){
+    Vertex t=DYADID2T(di), h=DYADID2H(di);
+    //Rprintf("d=%d di=%d t=%d h=%d ", d,di,t,h);
+    if((!DIRECTED && t>=h) || iEdgeListSearch(t,h,bl)) continue;
 
-      while(blpos < blnedges && 
-	    (t > bltails[blpos] || (t == bltails[blpos] && h > blheads[blpos]))) blpos++;
-      if(blpos < blnedges && t == bltails[blpos] && h == blheads[blpos]) continue;
-
-      int response = IS_OUTEDGE(t,h);
-      unsigned int totalStats = 0;
-      /* Let mtp loop through each model term */
-      for (ModelTerm *mtp=m->termarray; mtp < m->termarray + m->n_terms; mtp++){
-	mtp->dstats = newRow + totalStats;
-	/* Now call d_xxx function, which updates mtp->dstats to reflect
-	   changing the current dyad.  */
-	(*(mtp->d_func))(1, &t, &h, mtp, nwp);
-	/* dstats values reflect changes in current dyad; for MPLE, 
-	   values must reflect going from 0 to 1.  Thus, we have to reverse 
-	   the sign of dstats whenever the current edge exists. */
-	if(response){
+    int response = IS_OUTEDGE(t,h);
+    unsigned int totalStats = 0;
+    /* Let mtp loop through each model term */
+    for (ModelTerm *mtp=m->termarray; mtp < m->termarray + m->n_terms; mtp++){
+      mtp->dstats = newRow + totalStats;
+      /* Now call d_xxx function, which updates mtp->dstats to reflect
+	 changing the current dyad.  */
+      (*(mtp->d_func))(1, &t, &h, mtp, nwp);
+      /* dstats values reflect changes in current dyad; for MPLE, 
+	 values must reflect going from 0 to 1.  Thus, we have to reverse 
+	 the sign of dstats whenever the current edge exists. */
+      if(response){
 	  for(unsigned int l=0; l<mtp->nstats; l++){
 	    mtp->dstats[l] = -mtp->dstats[l];
 	  }
-	}
-	  /* Update mtp->dstats pointer to skip ahead by mtp->nstats */
-	  totalStats += mtp->nstats; 
-      }
-      /* In next command, if there is an offset vector then its total
-	 number of entries should match the number of times through the 
-	 inner loop (i.e., the number of dyads in the network) */          
-      if(!insCovMatRow(newRow, covmat, m->n_stats,
-		       maxNumDyadTypes, response, 
-		       responsevec, weightsvector)) {
-	error("Too many unique dyads!");
       }
+      /* Update mtp->dstats pointer to skip ahead by mtp->nstats */
+      totalStats += mtp->nstats; 
+    }
+    /* In next command, if there is an offset vector then its total
+       number of entries should match the number of times through the 
+       inner loop (i.e., the number of dyads in the network) */          
+    if(!insCovMatRow(newRow, covmat, m->n_stats,
+		     maxDyadTypes, response, 
+		     responsevec, weightsvector)) {
+      warning("Too many unique dyads. MPLE is approximate, and MPLE standard errors are suspect.");
+      break;
     }
   }
 }
 
 void MpleInit_hash_wl(int *responsevec, double *covmat, int *weightsvector,
-		   int *wltails, int *wlheads, Edge wlnedges, 
-		   Edge maxNumDyadTypes, Network *nwp, Model *m){
+		      int *wl, 
+		      Edge maxDyadTypes, Network *nwp, Model *m){
   double *newRow = (double *) R_alloc(m->n_stats,sizeof(double));
   /* Note:  This function uses macros found in changestat.h */
-  
-  for(Edge wlpos = 0; wlpos < wlnedges; wlpos++){
-    Vertex t=wltails[wlpos], h=wlheads[wlpos];
+  Edge wledges = wl[0];
+  wl++;
+
+  for(Edge wlpos = 0; wlpos < wledges; wlpos++){
+    Vertex t=wl[wlpos], h=(wl+wledges)[wlpos];
     
     int response = IS_OUTEDGE(t,h);
     unsigned int totalStats = 0;
@@ -214,9 +262,10 @@ void MpleInit_hash_wl(int *responsevec, double *covmat, int *weightsvector,
        number of entries should match the number of times through the 
        inner loop (i.e., the number of dyads in the network) */          
     if(!insCovMatRow(newRow, covmat, m->n_stats,
-		     maxNumDyadTypes, response, 
+		     maxDyadTypes, response, 
 		     responsevec, weightsvector)) {
-      error("Too many unique dyads!");
+      warning("Too many unique dyads. MPLE is approximate, and MPLE standard errors are suspect.");
+      break;
     }
   }
 }
