@@ -5,7 +5,7 @@
  *  open source, and has the attribution requirements (GPL Section 7) at
  *  http://statnet.org/attribution
  *
- *  Copyright 2003-2013 Statnet Commons
+ *  Copyright 2003-2014 Statnet Commons
  */
 #ifndef CHANGESTAT_H
 #define CHANGESTAT_H
@@ -78,7 +78,7 @@ double my_choose(double n, int r);
 #define TOGGLE_DISCORD(a,b) (ToggleEdge((a),(b),nwp+1));
 
 #define N_NODES (nwp->nnodes) /* Total number of nodes in the network */
-#define N_DYADS (nwp->directed_flag?(nwp->nnodes*(nwp->nnodes-1)):nwp->bipartite?nwp->bipartite*(nwp->nnodes-nwp->bipartite):(nwp->nnodes*(nwp->nnodes-1)/2))
+#define N_DYADS (DYADCOUNT(nwp->nnodes,nwp->bipartite,nwp->directed_flag))
 #define OUT_DEG (nwp->outdegree) /* Vector of length N_NODES giving current outdegrees */
 #define IN_DEG (nwp->indegree) /* Vector of length N_NODES giving current indegrees */
 #define DIRECTED (nwp->directed_flag) /* 0 if network is undirected, 1 if directed */
