@@ -1,12 +1,11 @@
-/*
- *  File ergm/src/netstats.h
- *  Part of the statnet package, http://statnet.org
+/*  File src/netstats.h in package ergm, part of the Statnet suite
+ *  of packages for network analysis, http://statnet.org .
  *
  *  This software is distributed under the GPL-3 license.  It is free,
- *  open source, and has the attribution requirements (GPL Section 7) in
- *    http://statnet.org/attribution
+ *  open source, and has the attribution requirements (GPL Section 7) at
+ *  http://statnet.org/attribution
  *
- *  Copyright 2012 the statnet development team
+ *  Copyright 2003-2014 Statnet Commons
  */
 #ifndef NETSTATS_H
 #define NETSTATS_H
@@ -17,7 +16,7 @@
 
 /* *** don't forget tail -> head, so these functions accept tails first, not heads */
 
-void network_stats_wrapper(int *tails, int *heads, int *timing, int *time, int *lasttoggle, int *dnedges, 
+void network_stats_wrapper(int *tails, int *heads, int *timings, int *time, int *lasttoggle, int *dnedges, 
 			   int *dn, int *dflag,  int *bipartite,
 			   int *nterms, char **funnames,
 			   char **sonames, double *inputs,  double *stats);
