@@ -1,12 +1,14 @@
-#  File ergm/tests/estflo.R
-#  Part of the statnet package, http://statnet.org
+#  File tests/estflo.R in package ergm, part of the Statnet suite
+#  of packages for network analysis, http://statnet.org .
 #
 #  This software is distributed under the GPL-3 license.  It is free,
-#  open source, and has the attribution requirements (GPL Section 7) in
-#    http://statnet.org/attribution
+#  open source, and has the attribution requirements (GPL Section 7) at
+#  http://statnet.org/attribution
 #
-#  Copyright 2012 the statnet development team
-######################################################################
+#  Copyright 2003-2013 Statnet Commons
+#######################################################################
+library(statnet.common)
+opttest({
 library(ergm)
 data(florentine)
 # a markov graph fit to the Florentine data
@@ -31,3 +33,4 @@ summary(gest)
 gest <- ergm(flomarriage ~ kstar(2), constraints=~edges, control=control.ergm(seed=16124))
 gest
 summary(gest)
+}, "Florentine")
