@@ -12,7 +12,7 @@ opttest({
 library(ergm)
 data(florentine)
  
-fit1 <- ergm(flomarriage ~ offset(edges) + kstar(2:3), offset.coef=1, control=control.ergm(MCMLE.maxit=3))
+fit1 <- ergm(flomarriage ~ offset(edges) + kstar(2:3), offset.coef=-1, control=control.ergm(MCMLE.maxit=3))
 
 print(summary(fit1))
 
