@@ -17,19 +17,19 @@ data(sampson)
 # MPLE
 summary(ergm(samplike~edges, control=control.ergm(drop=FALSE)))
 # MCMC
-summary(ergm(samplike~edges, control=control.ergm(drop=FALSE, force.main=TRUE)))
+summary(ergm(samplike~edges, control=control.ergm(drop=FALSE, force.main=TRUE, MCMLE.maxit=10)))
 
 ## Empty network.
 y0 <- network.initialize(10)
 # MPLE
 summary(ergm(y0~edges, control=control.ergm(drop=FALSE)))
 # MCMC
-summary(ergm(y0~edges, control=control.ergm(drop=FALSE, force.main=TRUE, init=0)))
+summary(ergm(y0~edges, control=control.ergm(drop=FALSE, force.main=TRUE, init=0, MCMLE.maxit=10)))
 
 ## Full network.
 y1 <- as.network(matrix(1,10,10))
 # MPLE
 summary(ergm(y1~edges, control=control.ergm(drop=FALSE)))
 # MCMC
-summary(ergm(y1~edges, control=control.ergm(drop=FALSE, force.main=TRUE, init=0)))
+summary(ergm(y1~edges, control=control.ergm(drop=FALSE, force.main=TRUE, init=0, MCMLE.maxit=10)))
 }, "drop disabled")
